/*  Init
 *
 *  This routine is the initialization task for this test program.
 *  It is called from init_exec and has the responsibility for creating
 *  and starting the tasks that make up the test.  If the time of day
 *  clock is required for the test, it should also be set to a known
 *  value by this function.
 *
 *  Input parameters:  NONE
 *
 *  Output parameters:  NONE
 *
 *  COPYRIGHT (c) 1989-1999.
 *  On-Line Applications Research Corporation (OAR).
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 *
 *  $Id: init.c,v 1.12 2003/09/04 18:53:41 joel Exp $
 */

#define CONFIGURE_INIT
#include "system.h"
#include <stdio.h>

/*
 *  Keep the names and IDs in global variables so another task can use them.
 */

rtems_id printMutex;

rtems_id Task_id[3];		/* array of task ids */
rtems_name Task_name[3];	/* array of task names */

rtems_task
Init (rtems_task_argument argument)
{

  rtems_status_code status;

  rtems_status_code sc;

  sc = rtems_semaphore_create (rtems_build_name ('P', 'm', 't', 'x'),
			       1,
			       RTEMS_PRIORITY | RTEMS_BINARY_SEMAPHORE |
			       RTEMS_INHERIT_PRIORITY |
			       RTEMS_NO_PRIORITY_CEILING | RTEMS_LOCAL, 0,
			       &printMutex);
  if (sc != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't create printf mutex:", rtems_status_text (sc));

  puts ("\n\n*** Multitask test ***");

  Task_name[0] = rtems_build_name ('D', 'M', 'C', '1');
  Task_name[1] = rtems_build_name ('D', 'M', 'C', '2');
  Task_name[2] = rtems_build_name ('D', 'M', 'C', '3');

  status =
    rtems_task_create (Task_name[0], 1, RTEMS_MINIMUM_STACK_SIZE * 2,
		       RTEMS_DEFAULT_MODES, RTEMS_DEFAULT_ATTRIBUTES,
		       &Task_id[0]);
		       
  if (status != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't create task 1:", rtems_status_text (status));
		       
  status =
    rtems_task_create (Task_name[1], 1, RTEMS_MINIMUM_STACK_SIZE * 2,
		       RTEMS_DEFAULT_MODES, RTEMS_DEFAULT_ATTRIBUTES,
		       &Task_id[1]);

  if (status != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't create task 2:", rtems_status_text (status));


  status =
    rtems_task_create (Task_name[2], 1, RTEMS_MINIMUM_STACK_SIZE * 2,
		       RTEMS_DEFAULT_MODES, RTEMS_DEFAULT_ATTRIBUTES,
		       &Task_id[2]);
		       
  if (status != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't create task 3:", rtems_status_text (status));
		       
  status = rtems_task_start (Task_id[0], Test_task_1, 1);

  if (status != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't start task 1:", rtems_status_text (status));

 
  status = rtems_task_start (Task_id[1], Test_task_2, 2);

  if (status != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't start task 2:", rtems_status_text (status));

  status = rtems_task_start (Task_id[2], Test_task_3, 3);

  if (status != RTEMS_SUCCESSFUL)
    rtems_panic ("Can't start task 3:", rtems_status_text (status));

  status = rtems_task_delete (RTEMS_SELF);
}
