/*
 *  Simple test program -- simplified version of sample test hello.
 */

#include <rtems.h>
#include <stdlib.h>
#include <stdio.h>

rtems_task
Init (rtems_task_argument arg)
{
  rtems_name name;
  rtems_id period;
  rtems_status_code status;

  rtems_interval ticks_per_second;
  rtems_clock_get( RTEMS_CLOCK_GET_TICKS_PER_SECOND, &ticks_per_second );
  printf("Configured with %u ticks per second\n",ticks_per_second);

  name = rtems_build_name ('P', 'E', 'R', 'D');

  status = rtems_rate_monotonic_create (name, &period);
  if (status != RTEMS_SUCCESSFUL)
    {
      printf ("rtems_monotonic_create failed with status of %d.\n", status);
      exit (1);
    }


  while (1)
    {
      if (rtems_rate_monotonic_period (period, 100) == RTEMS_TIMEOUT)
	break;

      /* Perform some periodic actions */
      printf("action!\n");
    }

  /* missed period so delete period and SELF */

  status = rtems_rate_monotonic_delete (period);
  if (status != RTEMS_SUCCESSFUL)
    {
      printf ("rtems_rate_monotonic_delete failed with status of %d.\n",
	      status);
      exit (1);
    }

  status = rtems_task_delete (RTEMS_SELF);	/* should not return */
  printf ("rtems_task_delete returned with status of %d.\n", status);
  exit (1);
}


/* configuration information */

#define CONFIGURE_APPLICATION_NEEDS_CONSOLE_DRIVER

#define CONFIGURE_APPLICATION_NEEDS_CLOCK_DRIVER

#define CONFIGURE_RTEMS_INIT_TASKS_TABLE

#define CONFIGURE_MAXIMUM_TASKS 1

#define CONFIGURE_MAXIMUM_PERIODS 1

#define CONFIGURE_MICROSECONDS_PER_TICK 10000

#define CONFIGURE_INIT

#include <rtems/confdefs.h>

/* end of file */
